/* This file will include set of functions
 * to store, retrieve and modify data from database.
 */

.import QtQuick.LocalStorage 2.0 as SQL


/* For internal usage in module.
 */
function openStdDataBase() {
    return SQL.LocalStorage.openDatabaseSync("RSS Reader", "1.0", "Feed DB", 10000)
}

function ensureTableExists(transaction) {
    transaction.executeSql('CREATE TABLE IF NOT EXISTS UserFeeds(link STRING PRIMARY KEY, displayName STRING, siteLink STRING, description STRING)')
}
/* Internal module usage end. */

/* This variable will store result of any operation with database.
 */
var dbResult

/* Load all feed from database.
 * Mb later we will need some criteria, such as tag, date and so on!
 */
function loadFeeds() {
    var db = openStdDataBase()

    db.transaction(function(tx) {
        ensureTableExists(tx)
        dbResult = tx.executeSql("SELECT * FROM UserFeeds")
        console.log("SELECTED: ", dbResult.rows.length)
    }
    )
}

/* Add feed to database.
 * Now only 3 fields, later - more (date, tag and etc.)
 */
function addFeed(link, displayName, siteLink, description) {
    displayName = displayName || ""
    siteLink = siteLink || ""
    description = description || ""

    var db = openStdDataBase()

    db.transaction(function (tx) {
        ensureTableExists(tx)
        dbResult = tx.executeSql('INSERT INTO UserFeeds VALUES(?, ?, ?, ?)', [link , displayName, siteLink, description])
        console.log("INSERT ID", dbResult.insertId)
    }
    )
}

function updateWithInfo(link, displayName, siteLink, description) {
    var db = openStdDataBase()

    db.transaction(function (tx) {
        ensureTableExists(tx)
        dbResult = tx.executeSql('UPDATE UserFeeds SET displayName=?, siteLink=?, description=? WHERE link=?', [displayName, siteLink, description, link])
        console.log("UPDATE, AFFECTED ROWS", dbResult.rowsAffected)
    }
    )
}

function deleteFeed(link) {
    var db = openStdDataBase()

    db.transaction(function (tx) {
        ensureTableExists(tx)
        dbResult = tx.executeSql('DELETE FROM UserFeeds WHERE link = ?', [link])
        console.log("DELETE, AFFECTED ROWS", dbResult.rowsAffected)
    }
    )
}

/* Only for debug purposes.
 */
function dropTable() {
    var db = openStdDataBase()

    db.transaction(function(tx) {
        tx.executeSql("DROP TABLE IF EXISTS UserFeeds")
        console.log("DATABASE DELETED")
    }
    )
}


